@@ -479,7 +479,6 @@ class Item(BaseItem):
         :returns: A dictionary containing the status_code and response
                   returned from the Metadata API.
         """
-        target = 'metadata' if target is None else target
         append = False if append is None else append
         access_key = self.session.access_key if not access_key else access_key
         secret_key = self.session.secret_key if not secret_key else secret_key
@@ -489,10 +488,9 @@ class Item(BaseItem):
         url = '{protocol}//archive.org/metadata/{identifier}'.format(
             protocol=self.session.protocol,
             identifier=self.identifier)
-        if any('/' in k for k in metadata):
-            source_metadata = self.item_metadata
-        else:
-            source_metadata = self.item_metadata.get(target.split('/')[0], {})
+        # TODO: currently files and metadata targets do not support dict's,
+        # but they might someday?? refactor this check.
+        source_metadata = self.item_metadata
         request = MetadataRequest(
             method='POST',
             url=url,
@@ -739,6 +737,7 @@ class Item(BaseItem):
                     body.close()
                     os.remove(filename)
                 body.close()
+                response.close()
                 return response
             except HTTPError as exc:
                 body.close()
