@@ -40,12 +40,14 @@ import requests.sessions
 from requests.utils import default_headers
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3 import Retry
+from six.moves.urllib.parse import urlparse
 
 from internetarchive import __version__
 from internetarchive.config import get_config
 from internetarchive.item import Item, Collection
 from internetarchive.search import Search
 from internetarchive.catalog import Catalog, CatalogTask
+from internetarchive.utils import reraise_modify
 
 
 logger = logging.getLogger(__name__)
@@ -118,7 +120,7 @@ class ArchiveSession(requests.sessions.Session):
             if debug or (logger.level <= 10):
                 self.set_file_logger(logging_config.get('level', 'NOTSET'),
                                      logging_config.get('file', 'internetarchive.log'),
-                                     'requests.packages.urllib3')
+                                     'urllib3')
 
     def _get_user_agent_string(self):
         """Generate a User-Agent string to be sent with every request."""
@@ -131,6 +133,14 @@ class ArchiveSession(requests.sessions.Session):
         return 'internetarchive/{0} ({1} {2}; N; {3}; {4}) Python/{5}'.format(
             __version__, uname[0], uname[-1], lang, self.access_key, py_version)
 
+    def rebuild_auth(self, prepared_request, response):
+        """Never rebuild auth for archive.org URLs.
+        """
+        u = urlparse(prepared_request.url)
+        if u.netloc.endswith('archive.org'):
+            return
+        super(ArchiveSession, self).rebuild_auth(prepared_request, response)
+
     def mount_http_adapter(self, protocol=None, max_retries=None,
                            status_forcelist=None, host=None):
         """Mount an HTTP adapter to the
@@ -370,7 +380,14 @@ class ArchiveSession(requests.sessions.Session):
         insecure = False
         with warnings.catch_warnings(record=True) as w:
             warnings.filterwarnings('always')
-            r = super(ArchiveSession, self).send(request, **kwargs)
+            try:
+                r = super(ArchiveSession, self).send(request, **kwargs)
+            except Exception as e:
+                try:
+                    reraise_modify(e, e.request.url, prepend=False)
+                except:
+                    logger.error(e)
+                    raise e
             if self.protocol == 'http:':
                 return r
             insecure_warnings = ['SNIMissingWarning', 'InsecurePlatformWarning']
